* [print-any-text](print-any-text/index.md)
* [print-croissant-desc](print-croissant-desc/index.md)
* [print-hello-world](print-hello-world/index.md)
* [print-hello-world-java](print-hello-world-java/index.md)
* [print-hello-world-javac](print-hello-world-javac/index.md)
* [print-hello-world-py](print-hello-world-py/index.md)
* [print-python-version](print-python-version/index.md)
* [run-python](run-python/index.md)
* [test-cm-core](test-cm-core/index.md)
* [test-cm-script-pipeline](test-cm-script-pipeline/index.md)
* [test-deps-conditions](test-deps-conditions/index.md)
* [test-deps-conditions2](test-deps-conditions2/index.md)
* [test-download-and-extract-artifacts](test-download-and-extract-artifacts/index.md)
* [test-set-sys-user-cm](test-set-sys-user-cm/index.md)
* [upgrade-python-pip](upgrade-python-pip/index.md)
